==> senior_design_system-0.15.4.tar.gz: CHANGELOG.md <==
# {version}
[{date}]

### Quebras de compatibilidade
* N/A.

### Novas funcionalidades
* N/A.

### Melhorias
* N/A.

### Correções
* N/A.

### Alterações na base de dados
* N/A.

### Alteração de dependências
* N/A.

# 0.15.4
[21/01/2022]

### Correções
* Opção de reduzir a qualidade de imagem para limitar seu tamanho no componente SeniorImageCropper [HCMAPP-183](https://jira.senior.com.br/browse/HCMAPP-183)
* Adicionando estado isLoading no componente SeniorProfilePicture [HCMAPP-183](https://jira.senior.com.br/browse/HCMAPP-183)

# 0.15.3
[21/01/2022]

### Correções
* Tamanho dos botões de acordo com o tamanho da tela no SeniorImageCropper [DSN-2859](https://jira.senior.com.br/browse/DSN-2859)

# 0.15.2
[14/01/2022]

### Correções
* Apresentando ícone de push no card apenas se tiver pushAction [DSN-2854](https://jira.senior.com.br/browse/DSN-2854)

# 0.15.1
[14/01/2022]

### Correções
* Deixando título do ContactBook como opcional [HCMAPP-157](https://jira.senior.com.br/browse/HCMAPP-157)

# 0.15.0
[12/01/2022]

### Novas funcionalidades
* Added *SeniorContactBookItem* component.

# 0.14.6
[31/12/2021]

### Fix
- *SeniorNotificationList* adjust push button padding and consider lower padding for some iOS devices.

### Features
- N/A

# 0.14.5

[{28/12/2021}]

### Fix

- *SeniorNotificationList* move the loading component to the item list and changes the button type from *secondary* to *ghost* and changed the button fullLength property to true.

# 0.14.4

[{28/12/2021}]

### Features

- Added *SeniorNotificationSnackbar*

# 0.14.3

[{28/12/2021}]

### Fix

- *SeniorNotificationList* add a scrollbar along with your controller.

### Features

# 0.14.2

[{28/12/2021}]

### Fix

- *SeniorSwitch* component resizing.

### Features

- Remove top padding in *SeniorNotificationList*.

# 0.14.1

[{27/12/2021}]

### Features

- isRead in *SeniorNotificationList* component.

# 0.14.0

[{24/12/2021}]

### Features

- Added *SeniorNotificationList* component.

# 0.13.1

[{20/12/2021}]

### Features

- Added *Dismissible* behavior in *SeniorCard* component.

# 0.13.0

[{20/12/2021}]

### Features

- Added *SeniorImageCropper* component.

# 0.12.0

[{13/12/2021}]

### Features

- Added *SeniorDraggableList* component.
- Added *SeniorMessageCard* component.

# 0.11.5

[{09/12/2021}]

### Features

- Revert property *hasTopShadow* on *SeniorColorfulHeaderStructure* component.

# 0.11.4

[09/12/2021]

### Features

- Added property *hasTopShadow* on *SeniorColorfulHeaderStructure* component.

# 0.11.3

[06/12/2021]

### Fix

- Adding the *itemPadding* and *itemSize* properties to the *SeniorRating* component.

# 0.11.2

[03/12/2021]

### Fix

- *SeniorSwitch* component resizing.

# 0.11.1

[02/12/2021]

### Fix

- Remove space from prefixIcon if there is no icon in *SeniorDropdownButton*. 

# 0.11.0

[01/12/2021]

### Features

- Added *SeniorAppBarCustom* component.

# 0.10.15

[29/11/2021]

### Fix

- Parameter to inform the label of the *SeniorTextField* component's counter and allow internationalization.
- Setting null value as default for *textInputAction* in *SeniorTextField* component.

# 0.10.14

[26/11/2021]

### Fix

- Title font resizing in *SeniorBottonSheet* component.


# 0.10.13

[25/11/2021]

### Fix

- Aligned label with hint text in *SeniorTextField* component.

# 0.10.12

[24/11/2021]

### Fix

- Not required icon in *SeniorMenuItemList* component.
- Aligned label and hint text in *SeniorTextField* component.
- Added textInputAction property in *SeniorTextField* component.
- Added onFieldSubmitted property in *SeniorTextField* component.

# 0.10.11

[23/11/2021]

### Feature

- Add title in *SeniorBottomSheet*.

# 0.10.10

[23/11/2021]

### Features

- Updating senior_desing_tokens version.

# 0.10.9

[19/11/2021]

### Fix

 - Padding fix in *SeniorMenuListItem* component.

# 0.10.8

[19/11/2021]

### Features

 - Added *SeniorBottomSheet* component.

# 0.9.8

[11/11/2021]

### Fix

 - Padding fix in *SeniorEvaluation* component.

# 0.9.7

[10/11/2021]

### Fix

 - Fix in *SeniorQuotes* component width.

# 0.9.6

[08/11/2021]

### Fix

 - Reduce radius of *SeniorColorfulHeaderStructure* component.

# 0.9.5

[04/11/2021]

### Fix

 - Size fix from *SeniorBottomNavigationBar* on iOS devices.

# 0.9.4

[01/11/2021]

### Fix

 - Fixed elements color from *SeniorAppBar*. 

# 0.9.3

[01/11/2021]

### Fix

 - Fixed the InkWell animation border radius from *SeniorCard*.
 - Fixed the InkWell animation border radius from *SeniorSquareButtonsMenu*.
 - Fixed border from *SeniorTextField*.

# 0.9.2

[29/10/2021]

### Fix

- Animation busy state in *SeniorButton* component.
- Added custom padding in *SeniorSquareButtonMenu*.

# 0.9.1

[29/10/2021]

### Fix

- Added *key* property in *SeniorSquareButtonsMenuItemData* class.

# 0.9.0

[28/10/2021]

### Features

- Added *SeniorTextField.password* component
- Fixed *SquareButtonsMenu* component that was transparent when there was no *Material* on top of it in the tree

# 0.8.5

[28/10/2021]

### Fix

- Added *duration* and *dismissDirection* properties in *SeniorSnackbar* component
- Color adjustment in SeniorMenuItemList component

# 0.8.4

[25/10/2021]

### Fix

- Added disabled state and checkbox in SeniorSquareButtonsMenu component
- Fixed issue that caused SeniorCard component not to execute onTap event
- Setting SeniorCheckbox background color when active

# 0.8.3

[25/10/2021]

### Fix

- Added wave effect to SeniorSquareButtonsMenu and SeniorCard components

# 0.7.3

[22/10/2021]

### Fix

- Removing *scroll* from *SeniorColorfulHeaderStructure*

# 0.7.2

[20/10/2021]

### Fix

- Added *ignoreGestures* in *SeniorRating* component

# 0.7.1

[20/10/2021]

### Fix

- Removed *disabled* parameter on *Chip* component

# 0.7.0

[19/10/2021]

### Features

- Added the following widgets:
    * SeniorProfileRating;

# 0.6.0

[19/10/2021]

### Features

- Added the following widgets:
    * SeniorLoading;
    * SeniorColorfulHeaderStructure;
    * SeniorEvaluation;
    * SeniorMenuListItem;
    * SeniorModal;
    * SeniorSquareButtonsMenu e
    * SeniorQuotes.

# 0.5.0

[13/10/2021]

### Features

- SeniorRating, SeniorCard added.

# 0.4.0

[04/10/2021]

### Features

- Added app with examples.

# 0.3.1

[29/09/2021]

### Features

- Font correction in Senior TextField component.

# 0.3.0

[21/09/2021]

### Features

- Senior Design System SeniorBalance widgtes available.

# 0.2.1

[17/09/2021]

### Features

- Updating senior_desing_tokens version.

# 0.2.0

[08/09/2021]

### Features

- Fixes in the SeniorTextField widget and obscureText property.
- SeniorDropdownButton widget available.
- SeniorExpansionPanelList available.
- SeniorInfoCard available.
- Fixes in the SeniorTopBar widget.
- widget documentation.

# 0.1.0

[09/08/2021]

### Features

- Senior Design System SeniorInfoCard widgtes available.

# 0.0.2

[28/07/2021]

### Features

- Senior Design System SeniorCheckbox, SeniorSwitch, SeniorTextField, SeniorTopBar widgtes available.

# 0.0.1

[14/07/2021]

### Features
- Senior Design System SeniorActionButton, SeniorBottomNavigationBar, SeniorButton, SeniorRadioButton, SeniorTabBar widgtes available.
- Senior Design System SeniorActionButton, SeniorBottomNavigationBar, SeniorButton, SeniorRadioButton, SeniorTabBar widgtes available.

==> senior_design_system-0.17.0.tar.gz: CHANGELOG.md <==
# 0.17.0
[18/03/2022]

### Melhorias
* Adicionando estrutura de temas para os componentes [DSN-2849](https://jira.senior.com.br/browse/DSN-2849).
* Adicionando os parâmetros iconColor e textColor no componente SeniorDraggableItem [DSN-2849](https://jira.senior.com.br/browse/DSN-2849).

# 0.16.0
[11/03/2022]

### Novas funcionalidades
* Criado o SeniorBackdrop [ERPAGRO-7481](https://jira.senior.com.br/browse/ERPAGRO-7481).

### Melhorias
* Os componentes SeniorColorfulHeaderStructure, SeniorAppBarHome, SeniorAppBarPage, SeniorAppBarCustom [ERPAGRO-7481](https://jira.senior.com.br/browse/ERPAGRO-7481).
* Adicionadas documentações de componentes  [DSN-2928](https://jira.senior.com.br/browse/DSN-2928).

# 0.15.15
[18/02/2022]

### Melhorias
* Adicionado o parâmetro "bottom" à SeniorAppBarCustom [DSN-3022](https://jira.senior.com.br/browse/DSN-3022).
* PreferredSize agora é configurado através do parâmetro "prefSize" na SeniorAppBar/Custom [DSN-3022](https://jira.senior.com.br/browse/DSN-3022).

# 0.15.14
[17/02/2022]

### Melhorias
* Componente SeniorBadge que irá substituir o SeniorEvaluation [DSN-2979](https://jira.senior.com.br/browse/DSN-2979).

# 0.15.13
[15/02/2022]

### Melhorias
* Ajustes nos espaçamentos do *SeniorSquareButtonsMenu* [HCMAPP-265](https://jira.senior.com.br/browse/HCMAPP-265)

# 0.15.12
[15/02/2022]

### Melhorias
* Definindo Navigation.pop como ação padrão para o botão de voltar do SeniorColorfulHeaderStructure [HCMAPP-257](https://jira.senior.com.br/browse/HCMAPP-257).

# 0.15.11
[14/02/2022]

### Melhorias
* Adicionado espaçamento embaixo respeitando o "notch" do IOS [HCMAPP-257](https://jira.senior.com.br/browse/HCMAPP-257)

# 0.15.10
[10/02/2022]

### Correções
* [DSN-2922](https://jira.senior.com.br/browse/DSN-2922) - Removendo cor de fundo adicionada abaixo dos checkbox no *SquareButtonMenu*.

# 0.15.9
[08/02/2022]

### Melhorias
* [DSN-2922](https://jira.senior.com.br/browse/DSN-2922) - Adicionando as propriedades *extraTapMargin* e *actionOnTitle* para permitir uma área maior de toque no checkbox e selecioná-lo a partir do title.

# 0.15.8
[31/01/2022]

### Correções
* Adicionado o elevation na SeniorAppBar para remover o problema de exibir sombras.
* Removido o Align do SeniorAppBarCustom, para que quando passe um leading null ele respeite o padrão da AppBar.
* Alterado o preferredSize de 100 para 50.

# 0.15.7
[31/01/2022]

### Correções
* Ajustes nas cores do componente SeniorCheckbox. [DSN-2909](https://jira.senior.com.br/browse/DSN-2909)

# 0.15.6
[27/01/2022]

### Correções
* Tamanho dos botões da tela de salvar imagem de acordo com o tamanho da tela no SeniorImageCropper. [N/A.](https://jira.senior.com.br/browse/DSN-2859)
* Usando Permission.photos para requisitar permissão para os arquivos de imagem. [N/A.](https://jira.senior.com.br/browse/DSN-2859)

# 0.15.5
[24/01/2022]

### Correções
* Condicionando a solicitação de permissão de acesso à câmera e arquivos no componente ImageCropper a dispositivos iOS. [DSN-2870](https://jira.senior.com.br/browse/DSN-2870)

# 0.15.4
[21/01/2022]

### Correções
* Opção de reduzir a qualidade de imagem para limitar seu tamanho no componente SeniorImageCropper. [HCMAPP-183](https://jira.senior.com.br/browse/HCMAPP-183)
* Adicionando estado isLoading no componente SeniorProfilePicture. [HCMAPP-183](https://jira.senior.com.br/browse/HCMAPP-183)

# 0.15.3
[21/01/2022]

### Correções
* Tamanho dos botões de acordo com o tamanho da tela no SeniorImageCropper. [DSN-2859](https://jira.senior.com.br/browse/DSN-2859)

# 0.15.2
[14/01/2022]

### Correções
* Apresentando ícone de push no card apenas se tiver pushAction. [DSN-2854](https://jira.senior.com.br/browse/DSN-2854)

# 0.15.1
[14/01/2022]

### Correções
* Deixando título do ContactBook como opcional. [HCMAPP-157](https://jira.senior.com.br/browse/HCMAPP-157)

# 0.15.0
[12/01/2022]

### Novas funcionalidades
* Added *SeniorContactBookItem* component.

# 0.14.6
[31/12/2021]

### Fix
- *SeniorNotificationList* adjust push button padding and consider lower padding for some iOS devices.

### Features
- N/A

# 0.14.5

[{28/12/2021}]

### Fix

- *SeniorNotificationList* move the loading component to the item list and changes the button type from *secondary* to *ghost* and changed the button fullLength property to true.

# 0.14.4

[{28/12/2021}]

### Features

- Added *SeniorNotificationSnackbar*

# 0.14.3

[{28/12/2021}]

### Fix

- *SeniorNotificationList* add a scrollbar along with your controller.

### Features

# 0.14.2

[{28/12/2021}]

### Fix

- *SeniorSwitch* component resizing.

### Features

- Remove top padding in *SeniorNotificationList*.

# 0.14.1

[{27/12/2021}]

### Features

- isRead in *SeniorNotificationList* component.

# 0.14.0

[{24/12/2021}]

### Features

- Added *SeniorNotificationList* component.

# 0.13.1

[{20/12/2021}]

### Features

- Added *Dismissible* behavior in *SeniorCard* component.

# 0.13.0

[{20/12/2021}]

### Features

- Added *SeniorImageCropper* component.

# 0.12.0

[{13/12/2021}]

### Features

- Added *SeniorDraggableList* component.
- Added *SeniorMessageCard* component.

# 0.11.5

[{09/12/2021}]

### Features

- Revert property *hasTopShadow* on *SeniorColorfulHeaderStructure* component.

# 0.11.4

[09/12/2021]

### Features

- Added property *hasTopShadow* on *SeniorColorfulHeaderStructure* component.

# 0.11.3

[06/12/2021]

### Fix

- Adding the *itemPadding* and *itemSize* properties to the *SeniorRating* component.

# 0.11.2

[03/12/2021]

### Fix

- *SeniorSwitch* component resizing.

# 0.11.1

[02/12/2021]

### Fix

- Remove space from prefixIcon if there is no icon in *SeniorDropdownButton*. 

# 0.11.0

[01/12/2021]

### Features

- Added *SeniorAppBarCustom* component.

# 0.10.15

[29/11/2021]

### Fix

- Parameter to inform the label of the *SeniorTextField* component's counter and allow internationalization.
- Setting null value as default for *textInputAction* in *SeniorTextField* component.

# 0.10.14

[26/11/2021]

### Fix

- Title font resizing in *SeniorBottonSheet* component.


# 0.10.13

[25/11/2021]

### Fix

- Aligned label with hint text in *SeniorTextField* component.

# 0.10.12

[24/11/2021]

### Fix

- Not required icon in *SeniorMenuItemList* component.
- Aligned label and hint text in *SeniorTextField* component.
- Added textInputAction property in *SeniorTextField* component.
- Added onFieldSubmitted property in *SeniorTextField* component.

# 0.10.11

[23/11/2021]

### Feature

- Add title in *SeniorBottomSheet*.

# 0.10.10

[23/11/2021]

### Features

- Updating senior_desing_tokens version.

# 0.10.9

[19/11/2021]

### Fix

 - Padding fix in *SeniorMenuListItem* component.

# 0.10.8

[19/11/2021]

### Features

 - Added *SeniorBottomSheet* component.

# 0.9.8

[11/11/2021]

### Fix

 - Padding fix in *SeniorEvaluation* component.

# 0.9.7

[10/11/2021]

### Fix

 - Fix in *SeniorQuotes* component width.

# 0.9.6

[08/11/2021]

### Fix

 - Reduce radius of *SeniorColorfulHeaderStructure* component.

# 0.9.5

[04/11/2021]

### Fix

 - Size fix from *SeniorBottomNavigationBar* on iOS devices.

# 0.9.4

[01/11/2021]

### Fix

 - Fixed elements color from *SeniorAppBar*. 

# 0.9.3

[01/11/2021]

### Fix

 - Fixed the InkWell animation border radius from *SeniorCard*.
 - Fixed the InkWell animation border radius from *SeniorSquareButtonsMenu*.
 - Fixed border from *SeniorTextField*.

# 0.9.2

[29/10/2021]

### Fix

- Animation busy state in *SeniorButton* component.
- Added custom padding in *SeniorSquareButtonMenu*.

# 0.9.1

[29/10/2021]

### Fix

- Added *key* property in *SeniorSquareButtonsMenuItemData* class.

# 0.9.0

[28/10/2021]

### Features

- Added *SeniorTextField.password* component
- Fixed *SquareButtonsMenu* component that was transparent when there was no *Material* on top of it in the tree

# 0.8.5

[28/10/2021]

### Fix

- Added *duration* and *dismissDirection* properties in *SeniorSnackbar* component
- Color adjustment in SeniorMenuItemList component

# 0.8.4

[25/10/2021]

### Fix

- Added disabled state and checkbox in SeniorSquareButtonsMenu component
- Fixed issue that caused SeniorCard component not to execute onTap event
- Setting SeniorCheckbox background color when active

# 0.8.3

[25/10/2021]

### Fix

- Added wave effect to SeniorSquareButtonsMenu and SeniorCard components

# 0.7.3

[22/10/2021]

### Fix

- Removing *scroll* from *SeniorColorfulHeaderStructure*

# 0.7.2

[20/10/2021]

### Fix

- Added *ignoreGestures* in *SeniorRating* component

# 0.7.1

[20/10/2021]

### Fix

- Removed *disabled* parameter on *Chip* component

# 0.7.0

[19/10/2021]

### Features

- Added the following widgets:
    * SeniorProfileRating;

# 0.6.0

[19/10/2021]

### Features

- Added the following widgets:
    * SeniorLoading;
    * SeniorColorfulHeaderStructure;
    * SeniorEvaluation;
    * SeniorMenuListItem;
    * SeniorModal;
    * SeniorSquareButtonsMenu e
    * SeniorQuotes.

# 0.5.0

[13/10/2021]

### Features

- SeniorRating, SeniorCard added.

# 0.4.0

[04/10/2021]

### Features

- Added app with examples.

# 0.3.1

[29/09/2021]

### Features

- Font correction in Senior TextField component.

# 0.3.0

[21/09/2021]

### Features

- Senior Design System SeniorBalance widgtes available.

# 0.2.1

[17/09/2021]

### Features

- Updating senior_desing_tokens version.

# 0.2.0

[08/09/2021]

### Features

- Fixes in the SeniorTextField widget and obscureText property.
- SeniorDropdownButton widget available.
- SeniorExpansionPanelList available.
- SeniorInfoCard available.
- Fixes in the SeniorTopBar widget.
- widget documentation.

# 0.1.0

[09/08/2021]

### Features

- Senior Design System SeniorInfoCard widgtes available.

# 0.0.2

[28/07/2021]

### Features

- Senior Design System SeniorCheckbox, SeniorSwitch, SeniorTextField, SeniorTopBar widgtes available.

# 0.0.1

[14/07/2021]

### Features
- Senior Design System SeniorActionButton, SeniorBottomNavigationBar, SeniorButton, SeniorRadioButton, SeniorTabBar widgtes available.
- Senior Design System SeniorActionButton, SeniorBottomNavigationBar, SeniorButton, SeniorRadioButton, SeniorTabBar widgtes available.
